@@ -1,6 +1,6 @@
 package Acme::Opish;
 
-use vars qw($VERSION); $VERSION = '0.05.1';
+use vars qw($VERSION); $VERSION = '0.01';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -48,7 +48,6 @@ my %OK; @OK{qw(
     Psyche
     psyche
     Quixote
-    recipie
     Sade
     Salome
     saute
@@ -62,6 +61,7 @@ my %OK; @OK{qw(
     tracheotome
     ukulele
     we
+    ye
     zimbabwe
 )} = undef;
 # }}}
@@ -125,7 +125,7 @@ sub _to_opish {
         $_ = lcfirst;
 
         # XXX Ack.  How can I simplify this ugliness?
-        if (exists $OK{ lc $_ }) {
+        if (exists $OK{lc $_}) {
             s/
                 (                   # Capture...
                     [aeiouy]+       # consecutive vowels
@@ -138,34 +138,8 @@ sub _to_opish {
                 )                   # ...end capture.
             /$prefix$1/gisx;        # Add 'op' to what we captured.
         }
-        # Special case 'ye'.
-        elsif (lc ($_) eq 'ye') {
-            $_ = 'y' . $prefix . substr ($_, -1);
-        }
-        # We don't want to prefix a non-vowel y.
-        elsif (/^y[aeiouy]/i) {
-            s/
-                (?:^y)?             # Our string starts with y, but we don't
-                                    # want to consider it for every match.
-                (                   # Capture...
-                    [aeiouy]+       # consecutive vowels
-                    \B              # that do not terminate at a word boundry
-                    (?![aeiouy])    # that are not followed by another vowel
-                    |               # or
-                    [aeiouy]*       # any consecutive vowels
-                    [aiouy]         # with any non-e vowel following
-                    \b              # that terminates at a word boundry.
-                    |               # or
-                    [aeiouy]+       # consecutive vowels
-                    [aeiouy]        # with any vowel following
-                    \b              # that terminates at a word boundry.
-                )                   # ...end capture.
-            /$prefix$1/gisx;        # Add 'op' to what we captured.
-
-            $_ = 'y' . $_;
-        }
-        # This regexp captures the "non-solitary, trailing e" vowels.
         else {
+            # This regexp captures the "non-solitary, trailing e" vowels.
             s/
                 (                   # Capture...
                     [aeiouy]+       # consecutive vowels
@@ -200,11 +174,13 @@ Acme::Opish - Prefix the audible vowels of words
 
   use Acme::Opish;
 
-  print enop('Hello Aeryk!');
+  print join (', ',
+      enop('Hello Aeryk!')
+  ), "\n";
   # Hopellopo Opaeropyk! 
 
-  @opped = enop('five', 'yellow', '/literature/Wuthering_Heights.txt');
-  # fopive, yopellopow, /literature/opish-Wuthering_Heights.txt
+  @opped = enop('five', '/literature/Wuthering_Heights.txt');
+  # fopive, /literature/opish-Wuthering_Heights.txt
 
   @opped = enop('xe', 'ze'));       # xe, ze
   @words = no_silent_e('xe', 'ze');
@@ -213,29 +189,33 @@ Acme::Opish - Prefix the audible vowels of words
   @opped = enop('xe', 'ze');        # xe, ze
 
   # Okay.  Why not add anything you want, instead of "op"?
-  print enop(-opish_prefix => 'ubb', 'Foo bar?');
+  print join (', ',
+      enop(-opish_prefix => 'ubb', 'Foo bar?')
+  ), "\n";
   # Fubboo bubbar?
 
+=head1 ABSTRACT
+
+Add an arbitrary prefix to the vowel groups of words (except for the 
+"silent e").
+
 =head1 DESCRIPTION
 
 Convert words to Opish, which is similar to "Ubish", but infinitely 
 cooler.
 
 More accurately, this means, add an arbitrary prefix to the vowel 
-groups of words, except for the "silent e" and "starting, non-vowel 
-y's".
+groups of words (except for the "silent e").
 
-Note: This module capitalizes words like you would expect.  Maybe a 
-couple examples will elucidate this point:
+Note: This module capitalized words beginning with a vowel to a 
+capitalized version with the prefix prepended.  Maybe a couple 
+examples will elucidate this point:
 
   enop('Abc') produces 'Opabc'
   enop('abC') produces 'opabC'
 
 Unfortunately, this function, currently converts consecutive spaces 
-and newlines into single spaces and newlines.  Yes, this is not a 
-feature, but a bug.
-
-* See the eg/ directory for examples.
+into a single space.  Yes, this is not a feature, but a bug.
 
 =head1 EXPORT
 
@@ -248,32 +228,32 @@ If it is an existing text file, it is opened and converted to opish,
 and then saved as "opish-$filename".
 
 If the first member of the argument list is "-opish_prefix", then the 
-next argument is assumed to be the user defined prefix to use in 
+next argument is assumed to be the user defined prefix to use, in 
 place of "op".
 
 =head2 no_silent_e ARRAY
 
-Add the given arguments to the list of words that are to be 
+Add the given arguments to the "OK" list of words that are to be 
 converted without regard for the "silent e".
 
-This function returns the keys in the "not silent e" list.
+This function returns the number of keys in the "OK" list.
 
 =head2 has_silent_e ARRAY
 
-Delete the given arguments from the list of words that are to be
+Delete the given arguments from the "OK" list of words that are to be
 converted with regard for the "silent e".
 
-This function returns the keys in the "not silent e" list.
+This function returns the number of keys in the "OK" list.
 
 =head1 SEE ALSO
 
 =head1 TO DO
 
-Make this thing preserve contiguous whitespace.
+Make this thing preserve contiguous spaces.
 
 Go in reverse.  That is "deop" text.
 
-Add more "non-silent-e" words to the "OK" list.
+Add more "OK" words".
 
 =head1 THANK YOU
 
@@ -285,7 +265,7 @@ Hopellopo Opaeropyk!
 
 =head1 AUTHOR
 
-Gopene Bopoggs, E<lt>gene@cpan.org<gt>
+Gopene Bopoggs, E<lt>cpan@ology.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
